@@ -983,7 +983,77 @@ se <- function(x, na.rm = FALSE) {
     }
 }
 
-
-
+#' Calculate the height or width in plot coordinates to keep a given ratio  
+#' relative to the figure. 
+#' 
+#' @import graphics
+#' @export
+#' @param input A number in units of x- or y-axis (determined by 
+#' \code{side.input} argument).
+#' @param original Two-number vector representing the width and height of the 
+#' original rectangle; alternatively, if only one number is provided, this is 
+#' interpreted as the width:height ratio.
+#' @param side.input Number representing the axis associated with the number(s) 
+#' specified in the argument \code{input}, with 1=bottom (default), 2=left, 
+#' 3=top, 4=right. The output is adjusted accordingly.
+#' @return Width and height in x- and y-units
+#' @family Utility functions
+#' @examples
+#' # add centered square to plot,
+#' # while plot window is not squared
+#' dev.new(width=5, height=4)
+#' emptyPlot(1,1, bty='o')
+#' size1 = keepFigRatio(.5, original=c(1,1))
+#' size2 = keepFigRatio(.5, original=c(1,1), side.input=2)
+#' rect(xleft=.5-(size1$x/2),
+#'      xright=.5+(size1$x/2),
+#'      ybottom=.5-(size1$y/2),
+#'      ytop=.5+(size1$y/2),
+#'      col="gray")
+#' rect(xleft=.5-(size2$x/2),
+#'      xright=.5+(size2$x/2),
+#'      ybottom=.5-(size2$y/2),
+#'      ytop=.5+(size2$y/2),
+#'      col=alpha("#FF3300"), border=NA)
+#' rect(xleft=.25, xright=.75,
+#'      ybottom=.25, ytop=.75,
+#'      lwd=2, border="#0066FF")
+#' 
+#' 
+keepFigRatio <- function(input, original=c(1024, 768), side.input=1){
+  if(length(original)==1){
+    original = c(original, 1)
+  }else if (length(original) > 2){
+    warning("Argument original should be a vector with 1 or 2 numbers.")
+  }
+  
+  # The current plot dimensions, (width, height), in inches.
+  plotIn = par()$pin 
+  # A vector of the form c(x1, x2, y1, y2) giving the extremes 
+  # of the user coordinates of the plotting region.
+  plotDim = par()$usr
+  
+  x.dim = plotDim[2]-plotDim[1]
+  y.dim = plotDim[4]-plotDim[3]
+  x.f = plotIn[1]/x.dim
+  y.f = plotIn[2]/y.dim
+  
+  if(length(original) != 2){
+    stop("original should be two-number vector with width and height of picture dimensions.")
+  }
+  if(side.input %in% c(1,3)){
+    ratio = original[2]/original[1]
+    input.in = x.f*input
+    output.in = input.in*ratio
+    output = output.in / y.f
+    return(list(x=input, y=output))
+  }else{
+    ratio = original[1]/original[2]
+    input.in = y.f*input
+    output.in = input.in*ratio
+    output = output.in / x.f
+    return(list(x=output,y=input))
+  }
+} 
 
 
